/*
   NAPI32MC.H - NAPI32 User functions and data structures (BSCV2)
   Copyright (c) 1996 Sangoma Technologies Inc.
   Author: Glenn Robins
   API v1.0, 32-bit, June 1996

   Application include file for NAPI32MC.DLL functions.
   See NAPI32.HLP for a complete function reference.

   Must #include <windows.h> before this header for type
   definitions used here.

   If compiling with Borland C, make sure structures are
   packed on byte boundaries. Link your application with
   NAPI32IM.DEF.

   If compiling with MS Visual C++ and for some reason
   you don't want to use __declspec(dllimport) then define
   SANGOMAIMPORT on the compiler command line. Link a VC++
   application using NAPI32MC.LIB.
*/

#ifndef SANGOMAAPI
#define SANGOMAAPI __cdecl
#endif

#ifdef SANGOMABUILD
#define SANGOMAIMPORT
#endif

#ifndef SANGOMAIMPORT
#if (_MSC_VER >= 800) && !defined(__STDC__)
#define SANGOMAIMPORT __declspec(dllimport)
#else
#define SANGOMAIMPORT
#endif
#endif

#ifndef SANGOMABUILD
#define	SDLAR_NOT_REGISTERED	0L
#define	SDLAR_DEREGISTERED		1L
#define	SDLAR_RELEASED			2L
#define	SDLAR_REGISTERED        1L
#define	SDLAR_ALLOCATED			2L
#define	SDLAR_CARD_BLOCKED		0L
#define	SDLAR_PREPARED			2L
#define	SDLAR_NOT_PREPARED		0L
#define	SDLAR_ERROR_PREPARING	3L
#endif


#define	MDATALEN	4000
#define	CB_HEADERLEN	15

/* for point-to-point, ignore station_number and address fields in CBLOCK */

/* note: structure must be packed on 1-byte boundaries
   and for a block this size, it is not wise to allocate it on
   the stack - should be a static global
*/
/* control block */
#ifdef _MSC_VER
#pragma pack(1)
#endif
typedef struct {
	BYTE command;
	WORD buffer_length;
	BYTE return_code;
	BYTE misc_tx_rx_bits;
	WORD heading_length;
	WORD notify;
	BYTE station;
	BYTE poll_address;
	BYTE select_address;
	BYTE device_address;
	BYTE notify_extended;
	BYTE reserved;
	BYTE data[MDATALEN];
} CBLOCK;
#ifdef _MSC_VER
#pragma pack()
#endif

#if defined (__cplusplus)
extern "C" {
#endif


/* NAPI will always return 1 */
SANGOMAIMPORT
int SANGOMAAPI NAPIAlive(void);

/* Initializes NAPI and loads SDLA driver, if not loaded already.
   A trace should be registered before this setup if one will
   be used at all, but is not necessary.
   Each application instance MUST call this on initialization.
   returns 0 if failed to load SDLA driver,
	   1 if this is the first setup call and the SDLA driver
	     loaded successfully,
	   2 if this is not the first successful setup call
	     (driver already loaded)
*/
SANGOMAIMPORT
int SANGOMAAPI NAPISetup(void);

/* Cleanup and unloads SDLA driver if this is the last
   application instance to use the driver.
   You must terminate your trace registration first if one
   was registered, unless you are the last application to use
   this DLL (but you shouldn't assume this).
   Each application instance MUST call this before closing.
   returns 1 always (return code reserved for future use)
*/
SANGOMAIMPORT
int SANGOMAAPI NAPICleanup(void);

/* Emulate BIP interrupt call with control block
   returns return_code value in structure
*/
SANGOMAIMPORT
char SANGOMAAPI NAPIControl(CBLOCK *block, BYTE cardnumber);

/* returns 0 if a debugging command trace is already registered or
   had difficulty creating the window, 1 if successful.
   hWnd is a window to send notification messages to, and
   iMessage is a user-defined message that NAPI will send the
   application to signal an NAPI notification. The actual
   message code is passed by value to the WPARAM parameter
   of the window procedure
*/
SANGOMAIMPORT
char SANGOMAAPI NAPIRegisterDebug(HINSTANCE hInstance, HWND hWnd, UINT iMessage);

/* if a debugging command trace is active and instance matches that passed
   when registered (for security/fault tolerance purposes) then
   trace is terminated and returns 0. If instance doesn't match,
   returns 1. If no trace is running, returns 2.
   The trace is also terminated automatically if the window is
   closed (see trace messages)
*/
SANGOMAIMPORT
char SANGOMAAPI NAPITerminateDebug(HINSTANCE hInstance);

/* returns TRUE if a debugging command trace is registered and active */
SANGOMAIMPORT
BOOL SANGOMAAPI NAPIIsDebugRegistered(void);

/* DEBUGGING COMMAND TRACE MESSAGES (wParam values) */
#define	TRACEMSG_CLOSE	0

/*
   returns SDLAR_NOT_REGISTERED (0L) if failed to obtain a selector
	(any read or write calls to the board will result
	in a general protection fault)
   returns SDLAR_REGISTERED if succeeded (1L): the card's
	instance count was incremented but this is not the
	first registration call for this board (it is already
	in use by an application)
   returns SDLAR_ALLOCATED if succeeded (2L): the card's
	instance count was incremented and this is the
	first registration call for this board, and the
	memory selector was allocated
*/
SANGOMAIMPORT
int SANGOMAAPI NAPIRegisterCard(BYTE cardnumber);

/*
   returns SDLAR_NOT_REGISTERED (0L) if card wasn't registered
   returns SDLAR_DEREGISTERED (1L) if card's instance count
	was decremented but isn't currently zero
	(i.e. an application is still using the specified board)
   returns SDLAR_RELEASED (2L) if card is now not used by
	any application, and the selector was freed
*/
SANGOMAIMPORT
int SANGOMAAPI NAPIDeregisterCard(BYTE cardnumber);

/*
   returns a bit record (32-bit) of cards registered for use
	and cards that exist:
	[ E15 E14 ... E3 E2 E1 E0 R15 R14 ... R3 R2 R1 R0 ]
   For example, if bit R2 is set, then card 2 is registered
		if bit E2 is set, then card 2 exists
			(i.e. a configuration entry exists
			in WIN.INI)
*/
SANGOMAIMPORT
LRESULT SANGOMAAPI NAPIGetCards(void);


/* Undocumented DLL exports - use at own risk */
SANGOMAIMPORT int SANGOMAAPI NAPIPrepareForLoading(BYTE cardnumber);
SANGOMAIMPORT int SANGOMAAPI NAPILoadComplete(BYTE cardnumber);
SANGOMAIMPORT unsigned char SANGOMAAPI NAPIReadPortByte(BYTE cardnumber, WORD offset);
SANGOMAIMPORT void SANGOMAAPI NAPIWritePortByte(BYTE cardnumber, WORD offset, BYTE data);
SANGOMAIMPORT unsigned char SANGOMAAPI NAPIReadByte(BYTE cardnumber, WORD offset);
SANGOMAIMPORT void SANGOMAAPI NAPIWriteByte(BYTE cardnumber, WORD offset, BYTE data);
SANGOMAIMPORT void SANGOMAAPI NAPIZeroWindow(BYTE cardnumber);


#ifdef __cplusplus
}
#endif
